# The IF Archive

The IF Archive is the central site on the Internet for text adventures and related interpreters, compilers and other tools. The Archive has an unrivalled collection of material relating to text adventures, including something in the region of two thousand games.

Formerly at the FTP site ftp.gmd.de, it is now at the web site http://www.ifarchive.org/. The Archive is also still accessible through FTP, at ftp://ftp.ifarchive.org/if-archive/. You might also like to consider using one of the Archive's mirror sites, which are listed on the Archive's home page: depending on where you are, you might well find a mirror that responds faster than the main Archive site.

The Archive's main collection of Glulx games is in the games/glulx directory. Another source of Glulx games is the annual IF Competition. Two other sites well worth a look are Baf's Guide to the Archive and Mike Robert's Interactive Fiction Database, both of which provide information and reviews of games in the IF Archive.